Feature

Struct Feature 

#[repr(transparent)]
pub struct Feature(pub i64);
Represents Arrow Features that might not have full support within implementations. This is intended to be used in two scenarios:

  1. A mechanism for readers of Arrow Streams and files to understand that the stream or file makes use of a feature that isn’t supported or unknown to the implementation (and therefore can meet the Arrow forward compatibility guarantees).
  2. A means of negotiating between a client and server what features a stream is allowed to use. The enums values here are intented to represent higher level features, additional details maybe negotiated with key-value pairs specific to the protocol.

Enums added to this list should be assigned power-of-two values to facilitate exchanging and comparing bitmaps for supported features.

Tuple Fields

0: i64

Implementations

Source

impl Feature

pub const UNUSED: Feature

Needed to make flatbuffers happy.

pub const DICTIONARY_REPLACEMENT: Feature

The stream makes use of multiple full dictionaries with the same ID and assumes clients implement dictionary replacement correctly.

pub const COMPRESSED_BODY: Feature

The stream makes use of compressed bodies as described in Message.fbs.

pub const ENUM_MIN: i64 = 0

pub const ENUM_MAX: i64 = 2

pub const ENUM_VALUES: &'static [Feature]

pub fn variant_name(self) -> Option<&'static str>

Returns the variant’s name or “” if unknown.