pub struct EncoderOptions { /* private fields */ }Expand description
Configuration options for the JSON encoder.
Implementations
Sourceimpl EncoderOptions
impl EncoderOptions
Sourcepub fn with_explicit_nulls(self, explicit_nulls: bool) -> EncoderOptions
pub fn with_explicit_nulls(self, explicit_nulls: bool) -> EncoderOptions
Set whether to include nulls in the output or elide them.
Sourcepub fn with_struct_mode(self, struct_mode: StructMode) -> EncoderOptions
pub fn with_struct_mode(self, struct_mode: StructMode) -> EncoderOptions
Set whether to encode structs as JSON objects or JSON arrays of their values.
Sourcepub fn with_encoder_factory(
self,
encoder_factory: Arc<dyn EncoderFactory>,
) -> EncoderOptions
pub fn with_encoder_factory( self, encoder_factory: Arc<dyn EncoderFactory>, ) -> EncoderOptions
Set an optional hook for customizing encoding behavior.
Sourcepub fn explicit_nulls(&self) -> bool
pub fn explicit_nulls(&self) -> bool
Get whether to include nulls in the output or elide them.
Sourcepub fn struct_mode(&self) -> StructMode
pub fn struct_mode(&self) -> StructMode
Get whether to encode structs as JSON objects or JSON arrays of their values.
Sourcepub fn encoder_factory(&self) -> Option<&Arc<dyn EncoderFactory>>
pub fn encoder_factory(&self) -> Option<&Arc<dyn EncoderFactory>>
Get the optional hook for customizing encoding behavior.