pub enum LogMsg {
SetStoreInfo(SetStoreInfo),
ArrowMsg(StoreId, ArrowMsg),
BlueprintActivationCommand(BlueprintActivationCommand),
}Expand description
The most general log message sent from the SDK to the server.
Note: this does not contain tables sent via TableMsg, as these concepts are fundamentally
different and should not be handled uniformly. For example, we don’t want to store tables in
.rrd files.
Variants
SetStoreInfo(SetStoreInfo)
A new recording has begun.
Should usually be the first message sent.
ArrowMsg(StoreId, ArrowMsg)
Log an entity using an ArrowMsg.
BlueprintActivationCommand(BlueprintActivationCommand)
Send after all messages in a blueprint to signal that the blueprint is complete.
This is so that the viewer can wait with activating the blueprint until it is fully transmitted. Showing a half-transmitted blueprint can cause confusion, and also lead to problems with view heuristics.
Implementations
Sourceimpl LogMsg
impl LogMsg
pub fn store_id(&self) -> &StoreId
pub fn set_store_id(&mut self, new_store_id: StoreId)
Sourcepub fn arrow_record_batch_mut(&mut self) -> Option<&mut RecordBatch>
pub fn arrow_record_batch_mut(&mut self) -> Option<&mut RecordBatch>
If we are an ArrowMsg, return a mutable reference to the underlying
ArrowRecordBatch.
pub fn insert_arrow_record_batch_metadata(&mut self, key: String, value: String)