pub struct GenericByteBuilder<T>where
T: ByteArrayType,{ /* private fields */ }Expand description
Builder for GenericByteArray
For building strings, see docs on GenericStringBuilder.
For building binary, see docs on GenericBinaryBuilder.
Implementations
Sourceimpl<T> GenericByteBuilder<T>where
T: ByteArrayType,
impl<T> GenericByteBuilder<T>where
T: ByteArrayType,
Sourcepub fn new() -> GenericByteBuilder<T>
pub fn new() -> GenericByteBuilder<T>
Creates a new GenericByteBuilder.
Sourcepub fn with_capacity(
item_capacity: usize,
data_capacity: usize,
) -> GenericByteBuilder<T>
pub fn with_capacity( item_capacity: usize, data_capacity: usize, ) -> GenericByteBuilder<T>
Creates a new GenericByteBuilder.
item_capacityis the number of items to pre-allocate. The size of the preallocated buffer of offsets is the number of items plus one.data_capacityis the total number of bytes of data to pre-allocate (for all items, not per item).
Sourcepub unsafe fn new_from_buffer(
offsets_buffer: MutableBuffer,
value_buffer: MutableBuffer,
null_buffer: Option<MutableBuffer>,
) -> GenericByteBuilder<T>
pub unsafe fn new_from_buffer( offsets_buffer: MutableBuffer, value_buffer: MutableBuffer, null_buffer: Option<MutableBuffer>, ) -> GenericByteBuilder<T>
Creates a new GenericByteBuilder from buffers.
Safety
This doesn’t verify buffer contents as it assumes the buffers are from
existing and valid GenericByteArray.
Sourcepub fn append_value(&mut self, value: impl AsRef<<T as ByteArrayType>::Native>)
pub fn append_value(&mut self, value: impl AsRef<<T as ByteArrayType>::Native>)
Appends a value into the builder.
See the GenericStringBuilder documentation for examples of
incrementally building string values with multiple write! calls.
Panics
Panics if the resulting length of Self::values_slice would exceed
T::Offset::MAX bytes.
For example, this can happen with StringArray or BinaryArray
where the total length of all values exceeds 2GB
Sourcepub fn append_option(
&mut self,
value: Option<impl AsRef<<T as ByteArrayType>::Native>>,
)
pub fn append_option( &mut self, value: Option<impl AsRef<<T as ByteArrayType>::Native>>, )
Append an Option value into the builder.
- A
Nonevalue will append a null value. - A
Somevalue will append the value.
See Self::append_value for more panic information.
Sourcepub fn append_null(&mut self)
pub fn append_null(&mut self)
Append a null value into the builder.
Sourcepub fn append_nulls(&mut self, n: usize)
pub fn append_nulls(&mut self, n: usize)
Appends n nulls into the builder.
Sourcepub fn append_array(&mut self, array: &GenericByteArray<T>)
pub fn append_array(&mut self, array: &GenericByteArray<T>)
Appends array values and null to this builder as is (this means that underlying null values are copied as is).
Sourcepub fn finish(&mut self) -> GenericByteArray<T>
pub fn finish(&mut self) -> GenericByteArray<T>
Builds the GenericByteArray and reset this builder.
Sourcepub fn finish_cloned(&self) -> GenericByteArray<T>
pub fn finish_cloned(&self) -> GenericByteArray<T>
Builds the GenericByteArray without resetting the builder.
Sourcepub fn values_slice(&self) -> &[u8] ⓘ
pub fn values_slice(&self) -> &[u8] ⓘ
Returns the current values buffer as a slice
Sourcepub fn offsets_slice(&self) -> &[<T as ByteArrayType>::Offset]
pub fn offsets_slice(&self) -> &[<T as ByteArrayType>::Offset]
Returns the current offsets buffer as a slice
Sourcepub fn validity_slice(&self) -> Option<&[u8]>
pub fn validity_slice(&self) -> Option<&[u8]>
Returns the current null buffer as a slice
Sourcepub fn validity_slice_mut(&mut self) -> Option<&mut [u8]>
pub fn validity_slice_mut(&mut self) -> Option<&mut [u8]>
Returns the current null buffer as a mutable slice